/*
 * @license
 * Copyright Ahmed Elywa. All Rights Reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 */
import { AccordionStyle } from './style';
import React from 'react';
import AccordionContext from './Context';
import { AccordionItem } from './Item';
const Accordion = /*#__PURE__*/React.forwardRef((props, ref) => {
  const [expanded, setExpanded] = React.useState(props.expanded ?? []);
  const [keys, setKeys] = React.useState([]);

  const handleAllState = state => {
    if (state) {
      const items = [];
      keys.forEach(key => !(props.disabled && props.disabled.includes(key)) && items.push(key));
      setExpanded(items);
    } else {
      setExpanded([]);
    }
  };

  const handleState = (state, uniqueKey) => {
    const index = expanded.indexOf(uniqueKey);
    const newKeys = [...expanded];

    if (index > -1 && !state) {
      newKeys.splice(index, 1);
    }

    if (index < 0 && state) {
      newKeys.push(uniqueKey);
    }

    setExpanded(newKeys);
  };

  const handleToggle = uniqueKey => {
    if (!props.disabled?.includes(uniqueKey)) {
      const index = expanded.indexOf(uniqueKey);

      if (props.multi) {
        const newKeys = [...expanded];

        if (index > -1) {
          newKeys.splice(index, 1);
        } else {
          newKeys.push(uniqueKey);
        }

        setExpanded(newKeys);
      } else {
        if (index > -1) {
          setExpanded([]);
        } else {
          setExpanded([uniqueKey]);
        }
      }
    }
  };

  React.useImperativeHandle(ref, () => ({
    openAll() {
      handleAllState(true);
    },

    closeAll() {
      handleAllState(false);
    },

    open(uniqueKey) {
      handleState(true, uniqueKey);
    },

    close(uniqueKey) {
      handleState(false, uniqueKey);
    },

    toggle(uniqueKey) {
      handleToggle(uniqueKey);
    }

  }), [expanded, keys, props.disabled]);
  return /*#__PURE__*/React.createElement(AccordionContext.Provider, {
    value: {
      expanded,
      setKeys,
      keys,
      handleToggle,
      disabled: props.disabled ?? []
    }
  }, /*#__PURE__*/React.createElement(AccordionStyle, {
    className: props.className
  }, props.children));
});
Accordion.displayName = 'Accordion';
export { AccordionItem, Accordion };