/*
 * @license
 * Copyright Ahmed Elywa. All Rights Reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 */
import styled, { css } from 'styled-components';
import React from 'react';
import { Icon } from '../Icon';
const FlipCardStyled = styled.div`
  ${({
  theme,
  flipped,
  button
}) => css`
    display: block;
    position: relative;
    perspective: 1200px;
    .flip-body {
      display: flex;
      transition: transform 0.5s;
      transform-style: preserve-3d;
      ${flipped ? 'transform: rotateY(-180deg);' : ''}
      & > .front,
      & > .back {
        flex: 1;

        .flip-button {
          line-height: ${theme.cardTextLineHeight};
          margin-bottom: ${theme.cardMarginBottom};
          padding: ${theme.cardPadding};
          cursor: pointer;
          position: absolute;
          ${theme.dir === 'rtl' ? 'left' : 'right'}: 0;
          ${button === 'bottom' ? 'bottom' : 'top'}: 0;
          opacity: 1;
          transition: opacity 0s 0.15s;
        }
      }

      & > .front {
        margin-${theme.dir === 'rtl' ? 'left' : 'right'}: -100%;
        transition: opacity 0s 0.2s;
        backface-visibility: visible;
        ${flipped && css`
            backface-visibility: hidden;
            opacity: 0;
            .flip-button {
              opacity: 0;
              z-index: -1;
            }
          `}
      }

      & > .back {
        backface-visibility: ${flipped ? 'visible' : 'hidden'};
        transform: rotateY(180deg);
      }
    }
  `}
`;

var _ref = /*#__PURE__*/React.createElement(Icon, {
  name: "chevron-right-outline"
});

var _ref2 = /*#__PURE__*/React.createElement(Icon, {
  name: "chevron-left-outline"
});

const FlipCard = props => {
  const [flipped, setFlipped] = React.useState(false);

  const handleFlipped = () => {
    setFlipped(!flipped);
  };

  return /*#__PURE__*/React.createElement(FlipCardStyled, {
    className: props.className,
    style: props.style,
    flipped: flipped,
    button: props.button
  }, /*#__PURE__*/React.createElement("div", {
    className: "flip-body"
  }, /*#__PURE__*/React.createElement("div", {
    className: "front"
  }, props.children[0], /*#__PURE__*/React.createElement("i", {
    className: "flip-button",
    onClick: handleFlipped
  }, _ref)), /*#__PURE__*/React.createElement("div", {
    className: "back"
  }, props.children[1], /*#__PURE__*/React.createElement("i", {
    className: "flip-button",
    onClick: handleFlipped
  }, _ref2))));
};

export default FlipCard;