/*
 * @license
 * Copyright Ahmed Elywa. All Rights Reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 */
import styled, { css } from 'styled-components';
import { outlineShadow, componentAnimation } from '../utils/Shared';
import IconStyle from '../Icon/style';
const CheckboxStyle = styled.label`
  ${({
  theme,
  checked,
  disabled,
  status,
  indeterminate
}) => css`
    position: relative;
    display: inline-flex;
    align-items: center;
    margin: 0;
    min-height: inherit;
    padding: ${theme.checkboxPadding};

    .custom-checkbox {
      width: ${theme.checkboxWidth};
      height: ${theme.checkboxHeight};
      border-style: ${theme.checkboxBorderStyle};
      border-width: ${theme.checkboxBorderWidth};
      border-radius: ${theme.checkboxBorderRadius};
      position: relative;
      flex-shrink: 0;
      ${componentAnimation('background-color, border, box-shadow')}
    }

    .native-input:focus:not(:checked) + .custom-checkbox {
      ${outlineShadow(theme.checkboxOutlineWidth, theme.checkboxOutlineColor, true)}
    }
    .native-input:focus:checked + .custom-checkbox {
      ${outlineShadow(theme.checkboxOutlineWidth, theme.checkboxOutlineColor)}
    }

    ${IconStyle} {
      position: absolute;
      top: 50%;
      left: 50%;
      transform: translate(-50%, -50%);
      width: 50%;
    }
    .text {
      font-family: ${theme.checkboxTextFontFamily};
      font-size: ${theme.checkboxTextFontSize};
      font-weight: ${theme.checkboxTextFontWeight};
      line-height: ${theme.checkboxTextLineHeight};
      transition: color 0.15s ease-in;
      &:not(:empty) {
        padding-${theme.dir === 'rtl' ? 'right' : 'left'}: ${theme.checkboxTextSpace};
      }
    }

    ${status && css`
        .custom-checkbox {
          background-color: ${theme[`checkbox${status}BackgroundColor`]};
          border-color: ${theme[`checkbox${status}BorderColor`]};
        }

        .text {
          color: ${theme[`checkbox${status}TextColor`]};
        }

        ${checked && css`
          .custom-checkbox {
            background-color: ${theme[`checkbox${status}CheckedBackgroundColor`]};
            border-color: ${theme[`checkbox${status}CheckedBorderColor`]};

            ${IconStyle} {
              color: ${theme[`checkbox${status}CheckedCheckmarkColor`]};
            }
          }
        `}
        ${indeterminate && css`
          .custom-checkbox {
            background-color: ${theme[`checkbox${status}IndeterminateBackgroundColor`]};
            border-color: ${theme[`checkbox${status}IndeterminateBorderColor`]};

            ${IconStyle} {
              color: ${theme[`checkbox${status}IndeterminateCheckmarkColor`]};
            }
          }
        `}

        .native-input:enabled:focus + .custom-checkbox {
          background-color: ${theme[`checkbox${status}FocusBackgroundColor`]};
          border-color: ${theme[`checkbox${status}FocusBorderColor`]};

          ${(indeterminate || checked) && css`
            background-color: ${theme[`checkbox${status}FocusCheckedBackgroundColor`]};
            border-color: ${theme[`checkbox${status}FocusCheckedBorderColor`]};
          `}
        }

        .custom-checkbox:hover {
          background-color: ${theme[`checkbox${status}HoverBackgroundColor`]};
          border-color: ${theme[`checkbox${status}HoverBorderColor`]};

          ${(indeterminate || checked) && css`
            background-color: ${theme[`checkbox${status}HoverCheckedBackgroundColor`]};
            border-color: ${theme[`checkbox${status}HoverCheckedBorderColor`]};
          `}
        }

        .native-input:enabled:active + .custom-checkbox {
          background-color: ${theme[`checkbox${status}ActiveBackgroundColor`]};
          border-color: ${theme[`checkbox${status}ActiveBorderColor`]};

          ${(indeterminate || checked) && css`
            background-color: ${theme[`checkbox${status}ActiveCheckedBackgroundColor`]};
            border-color: ${theme[`checkbox${status}ActiveCheckedBorderColor`]};
          `}
        }
        ${disabled && css`
          .native-input:disabled {
            & + .custom-checkbox {
              background-color: ${theme[`checkbox${status}DisabledBackgroundColor`]};
              border-color: ${theme[`checkbox${status}DisabledBorderColor`]};

              ${IconStyle} {
                color: ${theme[`checkbox${status}DisabledCheckmarkColor`]};
              }
            }
            & ~ .text {
              color: ${theme[`checkbox${status}DisabledTextColor`]};
            }
            &:indeterminate + .custom-checkbox,
            &:checked + .custom-checkbox {
              background-color: ${theme[`checkbox${status}DisabledCheckedBackgroundColor`]};
            }
          }
        `}
      `}
  `}
`;
export default CheckboxStyle;