/*
 * @license
 * Copyright Ahmed Elywa. All Rights Reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 */
import React from 'react';
import styled, { css } from 'styled-components';
import { breakpointUp, getGridSize, breakpoints, getGridGutter } from '@paljs/theme';
const BP = Object.keys(breakpoints);
const colData = css`
  ${({
  breakPoint,
  theme
}) => breakPoint && Object.keys(breakPoint).sort((k1, k2) => BP.indexOf(k1) - BP.indexOf(k2)).map(k => {
  if (typeof breakPoint[k] === 'number') {
    return breakpointUp(k)`
            flex: 0 0 ${100 / getGridSize(theme) * breakPoint[k]}%;
            max-width: ${100 / getGridSize(theme) * breakPoint[k]}%;
            display: block;`;
  } else if (breakPoint[k]) {
    return breakpointUp(k)`
            flex-grow: 1;
            flex-basis: 0;
            max-width: 100%;
            display: block;`;
  } else {
    return breakpointUp(k)`display: none;`;
  }
})}
`;
const offset = css`
  ${({
  offset,
  theme
}) => offset && Object.keys(offset).map(k => breakpointUp(k)`
          margin-${theme.dir == 'rtl' ? 'right' : 'left'}: 
          ${100 / getGridSize(theme) * offset[k]}%;`)}
`;
const ColStyle = styled.div`
  ${({
  theme,
  first,
  last,
  order
}) => css`
  position: relative;
  width: 100%;
  min-height: 1px;
  padding-right: ${getGridGutter(theme) / 2}px;
  padding-left: ${getGridGutter(theme) / 2}px;
  ${colData}
  ${offset}
  ${first && 'order: -1;'}
  ${last && `order: ${getGridSize(theme) + 1};`}
  ${order && `order: ${order};`}
`}
`;

const Col = props => /*#__PURE__*/React.createElement(ColStyle, props, props.children);

export default Col;