/*
 * @license
 * Copyright Ahmed Elywa. All Rights Reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 */
import React from 'react';
import { defaultIcons } from './defaultIcons';
import IconStyle from './style';
import { LayoutContext } from '../Layout';
export const Icon = props => {
  return /*#__PURE__*/React.createElement(IconStyle, {
    dangerouslySetInnerHTML: {
      __html: defaultIcons[props.name]
    },
    status: props.status,
    className: props.className
  });
};
export const EvaIcon = props => {
  const {
    evaIcons
  } = React.useContext(LayoutContext);
  let svgIcon = '';

  if (evaIcons && evaIcons[props.name]) {
    svgIcon = evaIcons[props.name](props.options);
  }

  return /*#__PURE__*/React.createElement(IconStyle, {
    dangerouslySetInnerHTML: {
      __html: svgIcon
    },
    status: props.status,
    className: props.className
  });
};
export const ItemIcon = ({
  icon,
  className
}) => {
  const {
    evaIcons
  } = React.useContext(LayoutContext);

  if (typeof icon === 'string') {
    if (icon in defaultIcons) {
      return /*#__PURE__*/React.createElement(Icon, {
        name: icon,
        className: className
      });
    } else if (evaIcons && icon in evaIcons) {
      return /*#__PURE__*/React.createElement(EvaIcon, {
        name: icon,
        className: className
      });
    } else {
      return /*#__PURE__*/React.createElement("i", {
        className: className + ' ' + icon
      });
    }
  } else if (typeof icon === 'object' && evaIcons && evaIcons[icon.name]) {
    icon.className += ' ' + className;
    return /*#__PURE__*/React.createElement(EvaIcon, icon);
  } else {
    return /*#__PURE__*/React.createElement(React.Fragment, null);
  }
};