/*
 * @license
 * Copyright Ahmed Elywa. All Rights Reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 */
import styled, { css } from 'styled-components';
import React from 'react';
import { componentAnimation } from '../utils/Shared';
const GroupStyle = styled.div`
  ${({
  theme,
  size,
  status,
  shape,
  fullWidth
}) => {
  return css`
      display: flex;
      min-width: 0;
      position: relative;

      input,
      textarea {
        border-style: ${theme.inputBorderStyle};
        border-width: ${theme.inputBorderWidth};
        font-family: ${theme.inputTextFontFamily};
        -webkit-appearance: none;

        ${componentAnimation('border, background-color, color, box-shadow')}
        
        ${fullWidth && 'width: 100%;'}

        &::placeholder {
          font-family: ${theme.inputPlaceholderTextFontFamily};
          text-overflow: ellipsis;
        }
        
        &:focus {
          outline: none;
        }
      
        ${status && css`
            background-color: ${theme[`input${status}BackgroundColor`]};
            border-color: ${theme[`input${status}BorderColor`]};
            color: ${theme[`input${status}TextColor`]};

            &::placeholder {
              color: ${theme[`input${status}PlaceholderTextColor`]};
            }

            &:focus {
              background-color: ${theme[`input${status}FocusBackgroundColor`]};
              border-color: ${theme[`input${status}FocusBorderColor`]};
            }
            &:hover {
              background-color: ${theme[`input${status}HoverBackgroundColor`]};
              border-color: ${theme[`input${status}HoverBorderColor`]};
            }

            &:disabled {
              background-color: ${theme[`input${status}DisabledBackgroundColor`]};
              border-color: ${theme[`input${status}DisabledBorderColor`]};
              color: ${theme[`input${status}DisabledTextColor`]};

              &::placeholder {
                color: ${theme[`input${status}DisabledPlaceholderTextColor`]};
              }
            }
          `}

        ${shape && css`
            border-radius: ${theme[`input${shape}BorderRadius`]};
          `}

        ${size && css`
            font-size: ${theme[`input${size}TextFontSize`]};
            font-weight: ${theme[`input${size}TextFontWeight`]};
            line-height: ${theme[`input${size}TextLineHeight`]};
            padding: ${theme[`input${size}Padding`]};

            ${!fullWidth && `max-width: ${theme[`input${size}MaxWidth`]};`}

            &::placeholder {
              font-size: ${theme[`input${size}PlaceholderTextFontSize`]};
              font-weight: ${theme[`input${size}PlaceholderTextFontWeight`]};
              line-height: ${theme[`input${size}PlaceholderTextLineHeight`]};
            }
          `}
      }
    `;
}}
`;
export const InputGroup = props => {
  return /*#__PURE__*/React.createElement(GroupStyle, props, props.children);
};
InputGroup.defaultProps = {
  size: 'Medium',
  shape: 'Rectangle',
  status: 'Basic'
};