/*
 * @license
 * Copyright Ahmed Elywa. All Rights Reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 */
import React from 'react';
import { LayoutStyle, LayoutContainer, LayoutContent, LayoutColumns, LayoutColumn, HeaderStyle, FooterStyle } from './style';
import LayoutContext from './layout-context';

const LayoutHeader = props => {
  const className = props.className ? props.className.split(' ') : [];
  props.fixed && className.push('fixed');
  return /*#__PURE__*/React.createElement(HeaderStyle, {
    className: className.join(' ')
  }, /*#__PURE__*/React.createElement("nav", null, props.children));
};

const LayoutFooter = props => {
  return /*#__PURE__*/React.createElement(FooterStyle, props, /*#__PURE__*/React.createElement("nav", null, props.children));
};

var _ref = /*#__PURE__*/React.createElement("div", {
  id: "overlay-container"
});

const Layout = props => {
  const [className, setClassName] = React.useState(props.className ? [...props.className.split(' ')] : []);
  const scrollRef = React.useRef(null);

  const addClass = cssClass => {
    const updatedClass = [...className];
    updatedClass.push(...cssClass);
    setClassName(updatedClass);
  };

  React.useEffect(() => {
    if ((props.withScroll || props.windowMode) && !className.includes('with-scroll')) {
      addClass(['with-scroll']);
      document.body.style.overflow = 'hidden';
    } else {
      document.body.style.overflow = 'initial';
    }
  }, [props.withScroll]);

  const removeClass = cssClass => {
    const updatedClass = [...className];

    for (const i of updatedClass.keys()) {
      if (cssClass.includes(updatedClass[i])) {
        updatedClass.splice(i, 1);
      }
    }

    setClassName(updatedClass);
  };

  const addEventListener = (event, listener, target = 'scrollArea') => {
    switch (target) {
      case 'Layout':
        document.getElementById('oah-layout').addEventListener(event, listener);
        break;

      default:
        if ((props.withScroll || props.windowMode) && scrollRef.current) {
          scrollRef?.current.addEventListener(event, listener);
        } else {
          window.addEventListener(event, listener);
        }

        break;
    }
  };

  const removeEventListener = (event, listener, target = 'scrollArea') => {
    switch (target) {
      case 'Layout':
        document.getElementById('oah-layout').removeEventListener(event, listener);
        break;

      default:
        if ((props.withScroll || props.windowMode) && scrollRef.current) {
          scrollRef?.current.removeEventListener(event, listener);
        } else {
          window.removeEventListener(event, listener);
        }

        break;
    }
  };

  return /*#__PURE__*/React.createElement(LayoutStyle, {
    id: "oah-layout",
    className: className.join(' '),
    style: props.style,
    withScroll: props.withScroll,
    windowMode: props.windowMode,
    withSubHeader: props.withSubHeader
  }, /*#__PURE__*/React.createElement(LayoutContext.Provider, {
    value: {
      addClass,
      removeClass,
      removeEventListener,
      addEventListener,
      dir: props.dir,
      evaIcons: props.evaIcons
    }
  }, /*#__PURE__*/React.createElement("div", {
    ref: scrollRef,
    className: "scrollable-container"
  }, /*#__PURE__*/React.createElement("div", {
    className: "layout"
  }, props.children)), _ref));
};

Layout.defaultProps = {
  dir: 'ltr'
};
export { Layout, LayoutHeader, LayoutContent, LayoutFooter, LayoutContainer, LayoutColumns, LayoutColumn, LayoutStyle, LayoutContext };