/*
 * @license
 * Copyright Ahmed Elywa. All Rights Reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 */
import React from 'react';
import { MenuStyle } from './style';
import Item from './Item';
const Menu = /*#__PURE__*/React.forwardRef((props, ref) => {
  const [items, setItems] = React.useState(props.items);
  const [expended, setExpended] = React.useState(false);

  const toggleSubMenu = (updateItems, action) => {
    for (const item of updateItems) {
      if (typeof action === 'boolean') {
        item.expanded = action;
      } else if (item === action) {
        item.expanded = !item.expanded;
        break;
      }

      if (item.children) {
        toggleSubMenu(item.children, action);
      }
    }

    return updateItems;
  };

  const toggleMenu = () => {
    setItems(toggleSubMenu([...items], !expended));
    setExpended(!expended);
  };

  React.useImperativeHandle(ref, () => ({
    toggle() {
      toggleMenu();
    }

  }));

  const updateSelected = (updateItems, ia) => {
    for (const item of updateItems) {
      const state = updateItems.indexOf(item) === ia[0];
      item.selected = state;

      if (state) {
        item.expanded = true;
      }

      if (item.children) {
        if (state) {
          updateSelected(item.children, ia.splice(1));
        } else {
          updateSelected(item.children, []);
        }
      }
    }

    return updateItems;
  };

  const onSelectItem = index => {
    setItems(updateSelected([...items], index));
  };

  const onToggleSubMenu = item => {
    setItems(toggleSubMenu([...items], item));
  };

  return /*#__PURE__*/React.createElement(MenuStyle, {
    className: props.className,
    style: props.style
  }, /*#__PURE__*/React.createElement("ul", {
    className: "menu-items"
  }, items.map((item, index) => {
    return !item.hidden && /*#__PURE__*/React.createElement(Item, {
      key: index,
      id: [index],
      item: item,
      Link: props.Link,
      nextJs: props.nextJs,
      currentPath: props.currentPath,
      selectItem: i => onSelectItem(i),
      toggleSidebar: props.toggleSidebar,
      toggleSubMenu: item => onToggleSubMenu(item)
    });
  })));
});
Menu.displayName = 'Menu';
export { Menu };