/*
 * @license
 * Copyright Ahmed Elywa. All Rights Reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 */
import styled, { css } from 'styled-components';
import { outlineShadow } from '../utils/Shared';
const RadioStyle = styled.label`
  ${({
  theme,
  status
}) => css`
    display: block;
    position: relative;
    label {
      display: inline-flex;
      margin: 0;
      min-height: inherit;
      padding: 0.375rem 0;
      padding-${theme.dir === 'rtl' ? 'left' : 'right'}: 1.5rem;
      align-items: center;
    }

    .outer-circle,
    .inner-circle {
      border-radius: 50%;
      position: absolute;
      top: 50%;
      ${theme.dir === 'rtl' ? 'right' : 'left'}: 0;
      transform: translateY(-50%);
      height: ${theme.radioHeight};
      width: ${theme.radioWidth};
    }

    .inner-circle {
      transform: translateY(-50%) scale(0.65);
    }

    .outer-circle {
      border-style: ${theme.radioBorderStyle};
      border-width: ${theme.radioBorderWidth};
    }

    .native-input:enabled:focus + .outer-circle {
      ${outlineShadow(theme.radioOutlineWidth, theme.radioOutlineColor)}
    }

    .text {
      font-family: ${theme.radioTextFontFamily};
      font-size: ${theme.radioTextFontSize};
      font-weight: ${theme.radioTextFontWeight};
      line-height: ${theme.radioTextLineHeight};
      margin-${theme.dir === 'rtl' ? 'right' : 'left'}: ${theme.radioWidth};
      padding-${theme.dir === 'rtl' ? 'right' : 'left'}: 0.5rem;
    }

    ${status && css`
        .native-input:enabled + .outer-circle {
          background-color: ${theme[`radio${status}BackgroundColor`]};
          border-color: ${theme[`radio${status}BorderColor`]};
        }

        .native-input:enabled:checked {
          & + .outer-circle {
            background-color: ${theme[`radio${status}CheckedBackgroundColor`]};
            border-color: ${theme[`radio${status}CheckedBorderColor`]};
          }
          & ~ .inner-circle {
            background-color: ${theme[`radio${status}InnerCircleColor`]};
          }
        }

        .native-input:enabled:focus + .outer-circle {
          border-color: ${theme[`radio${status}FocusBorderColor`]};
        }
        .native-input:enabled:checked:focus ~ .inner-circle {
          background-color: ${theme[`radio${status}FocusInnerCircleColor`]};
        }

        &:hover .native-input:enabled + .outer-circle {
          background-color: ${theme[`radio${status}HoverBackgroundColor`]};
          border-color: ${theme[`radio${status}HoverBorderColor`]};
        }
        &:hover .native-input:checked:enabled {
          + .outer-circle {
            background-color: ${theme[`radio${status}HoverCheckedBackgroundColor`]};
          }
          ~ .inner-circle {
            background-color: ${theme[`radio${status}HoverInnerCircleColor`]};
          }
        }

        .native-input:enabled:active + .outer-circle {
          border-color: ${theme[`radio${status}ActiveBorderColor`]};
        }
        .native-input:enabled:checked:active ~ .inner-circle {
          background-color: ${theme[`radio${status}ActiveInnerCircleColor`]};
        }

        .text {
          color: ${theme[`radio${status}TextColor`]};
        }

        .native-input:disabled {
          & + .outer-circle {
            background-color: ${theme[`radio${status}DisabledBackgroundColor`]};
            border-color: ${theme[`radio${status}DisabledBorderColor`]};
          }
          & ~ .text {
            color: ${theme[`radio${status}DisabledTextColor`]};
          }

          &:checked {
            & + .outer-circle {
              background-color: ${theme[`radio${status}DisabledCheckedBackgroundColor`]};
              border-color: ${theme[`radio${status}DisabledCheckedBorderColor`]};
            }
            ~ .inner-circle {
              background-color: ${theme[`radio${status}DisabledCheckedInnerCircleColor`]};
            }
          }
        }
      `}
    `}
`;
export default RadioStyle;