/*
 * @license
 * Copyright Ahmed Elywa. All Rights Reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 */
import React from 'react';
import { SearchStyle, SearchFieldStyle } from './style';
import Overlay from '../Overlay';
import layoutContext from '../Layout/layout-context';
import { Icon } from '../Icon';
import { Button } from '../Button';

var _ref = /*#__PURE__*/React.createElement(Icon, {
  name: "search-outline"
});

var _ref2 = /*#__PURE__*/React.createElement(Icon, {
  name: "close-outline"
});

export const Search = props => {
  const [value, setValue] = React.useState('');
  const [show, setShow] = React.useState();
  const inputRef = React.useRef(null);
  const layout = React.useContext(layoutContext);
  React.useEffect(() => {
    if (show === 'show') {
      inputRef.current?.focus();
    } else if (show === undefined) {
      layout.removeClass([props.type]);
    }
  }, [show]);

  const handleOpen = () => {
    setShow('');
    layout.addClass([props.type, 'with-search']);
    setTimeout(() => {
      setShow('show');
    }, 50);
  };

  const handleClose = () => {
    layout.removeClass(['with-search']);
    setShow('');
    setTimeout(() => {
      setShow(undefined);
    }, 200);
  };

  const onChangeHandle = e => {
    typeof props.onChange === 'function' && props.onChange(e.target.value);
    setValue(e.target.value);
  };

  return /*#__PURE__*/React.createElement(SearchStyle, {
    className: props.className
  }, /*#__PURE__*/React.createElement(Button, {
    appearance: "ghost",
    onClick: handleOpen
  }, _ref), show !== undefined && /*#__PURE__*/React.createElement(Overlay, null, /*#__PURE__*/React.createElement(SearchFieldStyle, {
    className: props.type + ' ' + show
  }, /*#__PURE__*/React.createElement("div", {
    className: "search",
    onKeyUp: e => {
      e.preventDefault();
      e.key === 'Escape' && handleClose();
    }
  }, /*#__PURE__*/React.createElement(Button, {
    appearance: "ghost",
    onClick: handleClose
  }, _ref2), /*#__PURE__*/React.createElement("div", {
    className: "form-wrapper"
  }, /*#__PURE__*/React.createElement("div", {
    className: "form"
  }, /*#__PURE__*/React.createElement("div", {
    className: "form-content"
  }, /*#__PURE__*/React.createElement("input", {
    ref: inputRef,
    onKeyUp: e => {
      e.preventDefault();

      if (e.key === 'Enter') {
        handleClose();
        props.submit(value);
      }
    },
    onChange: onChangeHandle,
    placeholder: props.placeholder,
    className: "search-input",
    autoComplete: "off",
    tabIndex: -1,
    value: value
  })), /*#__PURE__*/React.createElement("span", {
    className: "info"
  }, props.hint)))))));
};