/*
 * @license
 * Copyright Ahmed Elywa. All Rights Reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 */
import React from 'react';
import SidebarStyle from './style';
import { ifWidthInBreakpoint } from '@paljs/theme';
const Sidebar = /*#__PURE__*/React.forwardRef((props, ref) => {
  const [fixed, setFixed] = React.useState(props.fixed);
  const [state, setState] = React.useState(props.state);
  React.useImperativeHandle(ref, () => ({
    toggle() {
      switch (state) {
        case 'expanded':
          setState('compacted');
          break;

        case 'compacted':
          setState('expanded');
          break;

        case 'hidden':
          setState('visible');
          break;

        case 'visible':
          setState('hidden');
          break;
      }
    },

    hide() {
      if (state === 'visible') {
        setState('hidden');
      }
    }

  }), [state]);

  const mouseEnter = () => {
    if (state === 'compacted') {
      setState('expanded');
    }
  };

  const mouseLeave = () => {
    if (state === 'expanded' && ifWidthInBreakpoint(props.compactedBreakpoints)) {
      setState('compacted');
    }
  };

  React.useEffect(() => {
    const onMediaQueryChanges = () => {
      if (ifWidthInBreakpoint(props.hiddenBreakpoints)) {
        setState('hidden');
        setFixed(true);
      } else if (ifWidthInBreakpoint(props.compactedBreakpoints)) {
        setState('compacted');
        setFixed(true);
      } else {
        setState('expanded');
        setFixed(false);
      }
    };

    if (props.responsive) {
      onMediaQueryChanges();
      window.addEventListener('resize', onMediaQueryChanges);
    }

    return () => {
      window.removeEventListener('resize', onMediaQueryChanges);
    };
  }, []);
  typeof props.getState === 'function' && props.getState(state);
  const className = props.className ? props.className.split(' ') : [];
  className.push(state ?? '', props.property ?? '');
  fixed && className.push('fixed');
  return /*#__PURE__*/React.createElement(SidebarStyle, {
    className: className.join(' '),
    state: state,
    property: props.property,
    fixed: fixed,
    containerFixed: props.containerFixed,
    onMouseEnter: mouseEnter,
    onMouseLeave: mouseLeave
  }, /*#__PURE__*/React.createElement("div", {
    className: "main-container"
  }, props.children));
});

const SidebarBody = props => {
  return /*#__PURE__*/React.createElement("div", {
    className: "scrollable"
  }, props.children);
};

Sidebar.displayName = 'Sidebar';
Sidebar.defaultProps = {
  compactedBreakpoints: ['xs', 'is', 'sm', 'md', 'lg'],
  hiddenBreakpoints: ['xs', 'is'],
  property: 'start',
  state: 'expanded'
};
export { Sidebar, SidebarBody };