/*
 * @license
 * Copyright Ahmed Elywa. All Rights Reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 */
import React from 'react';
import TabsStyle from './style';
import Badge from '../Badge';
import { ItemIcon } from '../Icon';

const Tab = props => {
  return /*#__PURE__*/React.createElement("div", {
    className: "tab-content"
  }, props.children);
};

const Tabs = props => {
  const [tabs, setTabs] = React.useState([]);
  const [active, setActive] = React.useState(props.activeIndex ?? 0);

  const selectTab = index => {
    typeof props.onSelect === 'function' && props.onSelect(index);
    setActive(index);
  };

  React.useEffect(() => {
    const children = [];
    React.Children.forEach(props.children, child => {
      if (child.props.icon || child.props.title) {
        children.push({ ...child.props
        });
      }
    });
    setTabs(children);
  }, [props.children]);
  return /*#__PURE__*/React.createElement(TabsStyle, {
    className: props.className,
    style: props.style,
    fullWidth: props.fullWidth
  }, /*#__PURE__*/React.createElement("ul", {
    className: "tabs"
  }, tabs.map((tab, index) => {
    const cssClass = ['tab'];

    if (index === active) {
      cssClass.push('active');
    }

    if (tab.responsive) {
      cssClass.push('responsive');
    }

    if (tab.disabled) {
      cssClass.push('disabled');
    }

    if (tab.className) {
      cssClass.push(...tab.className.split(' '));
    }

    return /*#__PURE__*/React.createElement("li", {
      style: tab.style,
      key: index,
      className: cssClass.join(' '),
      onClick: () => !tab.disabled && selectTab(index)
    }, /*#__PURE__*/React.createElement("a", null, tab.icon && /*#__PURE__*/React.createElement(ItemIcon, {
      icon: tab.icon,
      className: "tabs-icon"
    }), tab.title && /*#__PURE__*/React.createElement("span", null, tab.title)), tab.badge && /*#__PURE__*/React.createElement(Badge, {
      status: tab.badge.status,
      position: tab.badge.position
    }, tab.badge.title));
  })), React.Children.map(props.children, (child, i) => {
    if (i === active && child.props.children) {
      return child;
    }
  }));
};

export { Tabs, Tab };